AuthResponse class

Constructors

AuthResponse({required String accessToken, String? refreshToken, required String userId, String? email, String? phone, String? dataRole, required int expiresInSec, int? refreshExpiresInSec})
AuthResponse.fromJson(Map<String, dynamic> j)
factory

Properties

accessToken String
final
dataRole String?
final
email String?
final
expiresInSec int
final
hashCode int
The hash code for this object.
no setterinherited
phone String?
final
refreshExpiresInSec int?
final
refreshToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited