MortarApiError class

Canonical error thrown by Mortar SDK operations.

Implemented types

Constructors

MortarApiError(int status, dynamic body, String endpoint, {String? requestId, int? retryAfterMs, Object? cause})
MortarApiError.transport(Object error, String endpoint)
factory

Properties

body → dynamic
final
category String
latefinal
cause Object?
final
code String
latefinal
endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
requestId String?
latefinal
retryable bool
latefinal
retryAfterMs int?
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited