MortarInsertBuilder class

Chainable insert / upsert builder. await it to run; it resolves to the created flat rows. Construct via from(table).insert(...).

Implemented types
Available extensions

Constructors

MortarInsertBuilder(ClientOptions _opts, String _table, List<Map<String, dynamic>> _rows, {bool single = false, bool upsert = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSPromise<T>

Available on Future<T>, provided by the FutureOfJSAnyToJSPromise extension

A JSPromise that either resolves with the result of the completed Future or rejects with an object that contains its error.
no setter
toJS JSPromise<JSAny?>

Available on Future<void>, provided by the FutureOfVoidToJSPromise extension

A JSPromise that either resolves once this Future completes or rejects with an object that contains its error.
no setter

Methods

asStream() Stream
Creates a Stream containing the result of this future.
override
catchError(Function onError, {bool test(Object error)?}) Future
Handles errors emitted by this Future.
override
ignore() → void

Available on Future<T>, provided by the FutureExtensions extension

Completely ignores this future and its result.
maybeSingle() Future<Map<String, dynamic>?>
Resolve to one created row or null (throws if more than one).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError<E extends Object>(FutureOr<T> handleError(E error, StackTrace stackTrace), {bool test(E error)?}) Future<T>

Available on Future<T>, provided by the FutureExtensions extension

Handles errors on this future.
single() Future<Map<String, dynamic>>
Resolve to the single created row (throws if not exactly one was created).
then<R>(FutureOr<R> onValue(dynamic value), {Function? onError}) Future<R>
Register callbacks to be called when this future completes.
override
timeout(Duration timeLimit, {FutureOr onTimeout()?}) Future
Stop waiting for this future after timeLimit has passed.
override
toString() String
A string representation of this object.
inherited
whenComplete(FutureOr<void> action()) Future
Registers a function to be called when this future completes.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited