MortarSession class

A session — supabase Session shape (the fields Mortar carries).

Constructors

MortarSession({required String accessToken, String? refreshToken, String tokenType = 'bearer', int? expiresIn, required MortarUser user})

Properties

accessToken String
final
expiresIn int?
Seconds until the access token expires (from the login response).
final
hashCode int
The hash code for this object.
no setterinherited
refreshToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenType String
final
user MortarUser
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited