RealtimeEvent class
A change event emitted by the realtime SSE stream.
Constructors
- RealtimeEvent({required String op, required String id, required dynamic data})
Properties
- data → dynamic
-
New row data on INSERT/UPDATE, old row data on DELETE.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
UUID of the row that changed.
final
- op → String
-
"INSERT" | "UPDATE" | "DELETE".
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited