AccountInfo class
Constructors
-
AccountInfo({required String id, required String email, String? name, String? subscriptionPlan, String? subscriptionValidUntil, double? subscriptionMonthlyFeeYuan, double? subscriptionComputeGrantYuan, String? subscriptionSettlementKind, required bool subscriptionContractOnly, required List<
String> allowedComputeSpecs, int? maxActiveProjects, required String createdAt}) -
AccountInfo.fromJson(Map<
String, dynamic> j) -
factory
Properties
-
allowedComputeSpecs
→ List<
String> -
final
- createdAt → String
-
final
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- maxActiveProjects → int?
-
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionComputeGrantYuan → double?
-
final
- subscriptionContractOnly → bool
-
final
- subscriptionMonthlyFeeYuan → double?
-
final
- subscriptionPlan → String?
-
final
- subscriptionSettlementKind → String?
-
final
- subscriptionValidUntil → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited