PresenceEntry class
One member's presence entry as seen by other clients on a channel.
Constructors
- PresenceEntry({required String ref, required String key, dynamic state})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Presence key (the identity chosen via
channel(name, key: ...)).final - ref → String
-
Per-connection id (unique per tab/device).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → dynamic
-
The arbitrary state the member tracked (cursor, name, colour, …).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited