TopupResponse class
Constructors
- TopupResponse({required String provider, required String externalRef, String? qrCodeData, String? redirectUrl, int? expiresAtUnixSec})
-
TopupResponse.fromJson(Map<
String, dynamic> j) -
factory
Properties
- expiresAtUnixSec → int?
-
final
- externalRef → String
-
Payment processor's transaction id (used as the idempotency key).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider → String
-
final
- qrCodeData → String?
-
Scan-to-pay QR payload (alipay scan / wechat native).
final
- redirectUrl → String?
-
Hosted-checkout redirect URL (alipay page flow).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited