UsageSummary class
Usage / credit summary returned by /v1/usage/me.
Constructors
-
UsageSummary({required String projectId, required String billingPeriod, required String tier, required String creditMode, required double grantedYuan, required double usedYuan, required double balanceYuan, required Map<
String, double> usedByResource}) -
UsageSummary.fromJson(Map<
String, dynamic> j) -
factory
Properties
- balanceYuan → double
-
final
- billingPeriod → String
-
final
- creditMode → String
-
final
- grantedYuan → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tier → String
-
final
-
usedByResource
→ Map<
String, double> -
final
- usedYuan → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited